==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/MutatingWebhookConfigurationListBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class MutatingWebhookConfigurationListBuilder extends MutatingWebhookConfigurationListFluentImpl<MutatingWebhookConfigurationListBuilder> implements VisitableBuilder<MutatingWebhookConfigurationList,MutatingWebhookConfigurationListBuilder> {

    MutatingWebhookConfigurationListFluent<?> fluent;
    Boolean validationEnabled;

    public MutatingWebhookConfigurationListBuilder() {
        this(true);
    }

    public MutatingWebhookConfigurationListBuilder(Boolean validationEnabled) {
        this(new MutatingWebhookConfigurationList(), validationEnabled);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent) {
        this(fluent, true);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new MutatingWebhookConfigurationList(), validationEnabled);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent,MutatingWebhookConfigurationList instance) {
        this(fluent, instance, true);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent,MutatingWebhookConfigurationList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationList instance) {
        this(instance,true);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public MutatingWebhookConfigurationList build() {
        MutatingWebhookConfigurationList buildable = new MutatingWebhookConfigurationList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        MutatingWebhookConfigurationListBuilder that = (MutatingWebhookConfigurationListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/MutatingWebhookConfigurationListBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class MutatingWebhookConfigurationListBuilder extends MutatingWebhookConfigurationListFluentImpl<MutatingWebhookConfigurationListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<MutatingWebhookConfigurationList,MutatingWebhookConfigurationListBuilder> {

    MutatingWebhookConfigurationListFluent<?> fluent;
    Boolean validationEnabled;

    public MutatingWebhookConfigurationListBuilder() {
        this(true);
    }

    public MutatingWebhookConfigurationListBuilder(Boolean validationEnabled) {
        this(new MutatingWebhookConfigurationList(), validationEnabled);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent) {
        this(fluent, true);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new MutatingWebhookConfigurationList(), validationEnabled);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent,MutatingWebhookConfigurationList instance) {
        this(fluent, instance, true);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationListFluent<?> fluent,MutatingWebhookConfigurationList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationList instance) {
        this(instance,true);
    }

    public MutatingWebhookConfigurationListBuilder(MutatingWebhookConfigurationList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public MutatingWebhookConfigurationList build() {
        MutatingWebhookConfigurationList buildable = new MutatingWebhookConfigurationList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        MutatingWebhookConfigurationListBuilder that = (MutatingWebhookConfigurationListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
